work on chan_lcr: bridging works, interface selection possible
[lcr.git] / mISDN.h
diff --git a/mISDN.h b/mISDN.h
index 32ed6d8..f9bae48 100644 (file)
--- a/mISDN.h
+++ b/mISDN.h
 extern int entity;
 extern int mISDNdevice;
 
+enum {
+       B_EVENT_USE,            /* activate/export bchannel */
+       B_EVENT_EXPORTREQUEST,  /* remote app requests bchannel */
+       B_EVENT_IMPORTREQUEST,  /* remote app releases bchannel */
+       B_EVENT_ACTIVATED,      /* DL_ESTABLISH received */
+       B_EVENT_DROP,           /* deactivate/re-import bchannel */
+       B_EVENT_DEACTIVATED,    /* DL_RELEASE received */
+       B_EVENT_EXPORTED,       /* BCHANNEL_ASSIGN received */
+       B_EVENT_IMPORTED,       /* BCHANNEL_REMOVE received */
+       B_EVENT_TIMEOUT,        /* timeout for bchannel state */
+};
+
 /* mISDN port structure list */
 struct mISDNport {
-       net_stack_t nst; /* MUST be the first entry, so &nst equals &mISDNlist */
-       manager_t mgr;
+       struct mlayer3 *ml3;
        struct mISDNport *next;
+       char name[64]; /* name of port, if available */
        struct interface_port *ifport; /* link to interface_port */
 //     int iftype; /* IF_* */
 //     int multilink; /* if set, this port will not support callwaiting */
-       int portnum; /* port number */
+       int portnum; /* port number 1..n */
        int ptp; /* if ptp is set, we keep track of l2link */
        int l1link; /* if l1 is available (only works with nt-mode) */
        int l2link; /* if l2 is available (at PTP we take this serious) */
-//     time_t l1timeout; /* timout when establishing link */
+       int l2hold; /* set, if layer 2 must be hold/checked */
        time_t l2establish; /* time until establishing after link failure */
        int use; /* counts the number of port that uses this port */
        int ntmode; /* is TRUE if port is nt mode */
        int pri; /* is TRUE if port is a primary rate interface */
        int tones; /* TRUE if tones are sent outside connect state */
        int earlyb; /* TRUE if tones are received outside connect state */
-       int upper_id; /* id to transfer data down */
-       int lower_id; /* id to transfer data up */
-       int d_stid;
        int b_num; /* number of bchannels */
        int b_reserved; /* number of bchannels reserved or in use */
        class PmISDN *b_port[128]; /* bchannel assigned to port object */
-       int b_stid[128];
-       unsigned long b_addr[128];
+       struct mqueue upqueue;
+       int b_socket[128];
        int b_state[128]; /* statemachine, 0 = IDLE */
+       double b_timer[128]; /* timer for state machine */
        unsigned long b_remote_id[128]; /* the socket currently exported */
        unsigned long b_remote_ref[128]; /* the ref currently exported */
-       int procids[128]; /* keep track of free ids */
        int locally; /* local causes are sent as local causes not remote */
-       msg_queue_t downqueue;          /* l4->l3 */
+       int los, ais, rdi, slip_rx, slip_tx;
 };
 extern mISDNport *mISDNport_first;
 
@@ -70,22 +79,19 @@ calls with no bchannel (call waiting, call on hold).
 int mISDN_initialize(void);
 void mISDN_deinitialize(void);
 void mISDN_port_info(void);
-struct mISDNport *mISDNport_open(int port, int ptp, int ptmp, struct interface *interface);
+struct mISDNport *mISDNport_open(int port, int ptp, int force_nt, int l2hold, struct interface *interface);
 void mISDNport_close_all(void);
 void mISDNport_close(struct mISDNport *mISDNport);
 void mISDN_port_reorder(void);
 int mISDN_handler(void);
-void enc_ie_cause_standalone(unsigned char **ntmode, msg_t *msg, int location, int cause);
-void ph_control(struct mISDNport *mISDNport, class PmISDN *isdnport, unsigned long b_addr, int c1, int c2, char *trace_name, int trace_value);
-void ph_control_block(struct mISDNport *mISDNport, unsigned long b_addr, int c1, void *c2, int c2_len, char *trace_name, int trace_value);
-msg_t *create_l2msg(int prim, int dinfo, int size);
-void setup_queue(struct mISDNport *mISDNport, int link);
-int stack2manager_nt(void *dat, void *arg);
-int stack2manager_te(struct mISDNport *mISDNport, msg_t *msg);
+void enc_ie_cause_standalone(struct l3_msg *l3m, int location, int cause);
+int stack2manager(struct mISDNport *mISDNport, unsigned int cmd, unsigned int pid, struct l3_msg *l3m);
+void ph_control(struct mISDNport *mISDNport, class PmISDN *isdnport, unsigned long handle, unsigned long c1, unsigned long c2, char *trace_name, int trace_value);
+void ph_control_block(struct mISDNport *mISDNport, unsigned long handle, unsigned long c1, void *c2, int c2_len, char *trace_name, int trace_value);
 void chan_trace_header(struct mISDNport *mISDNport, class PmISDN *port, char *msgtext, int direction);
 void l1l2l3_trace_header(struct mISDNport *mISDNport, class PmISDN *port, unsigned long prim, int direction);
 void bchannel_event(struct mISDNport *mISDNport, int i, int event);
-void message_bchannel_from_join(class JoinRemote *joinremote, int type, unsigned long addr);
+void message_bchannel_from_remote(class JoinRemote *joinremote, int type, unsigned long handle);
 
 
 /* mISDN port classes */
@@ -94,7 +100,7 @@ class PmISDN : public Port
        public:
        PmISDN(int type, struct mISDNport *mISDNport, char *portname, struct port_settings *settings, int channel, int exclusive);
        ~PmISDN();
-       void bchannel_receive(iframe_t *frm);
+       void bchannel_receive(struct mISDNhead *hh, unsigned char *data, int len);
        int handler(void);
        void transmit(unsigned char *buffer, int length);
        int message_epoint(unsigned long epoint_id, int message, union parameter *param);
@@ -102,7 +108,8 @@ class PmISDN : public Port
        void message_crypt(unsigned long epoint_id, int message_id, union parameter *param);
        struct mISDNport *p_m_mISDNport;        /* pointer to port */
        int p_m_delay;                          /* use delay instead of dejitter */
-       int p_m_txvol, p_m_rxvol;               /* volume shift (0 = no change) */
+       int p_m_tx_gain, p_m_rx_gain;           /* volume shift (0 = no change) */
+       char p_m_pipeline[256];                 /* filter pipeline */
        int p_m_echo, p_m_conf;                 /* remote echo, conference number */
        int p_m_tone;                           /* current kernel space tone */
        int p_m_rxoff;                          /* rx from driver is disabled */